@@ -417,9 +417,9 @@ registerChannelValue(supybot.reply.mores, 'instant',
 
 registerChannelValue(supybot.reply, 'oneToOne',
     registry.Boolean(True, _("""Determines whether the bot will send
-    multi-message replies in a single message or in multiple messages.  For
-    safety purposes (so the bot is less likely to flood) it will normally send
-    everything in a single message, using mores if necessary.""")))
+    multi-message replies in a single message. This defaults to True 
+    in order to prevent the bot from flooding. If this is set to False
+    the bot will send multi-message replies on multiple lines.""")))
 
 registerChannelValue(supybot.reply, 'whenNotCommand',
     registry.Boolean(True, _("""Determines whether the bot will reply with an
@@ -757,10 +757,10 @@ class ValidDriverModule(registry.OnlySomeStrings):
     validStrings = ('default', 'Socket', 'Twisted')
 
 registerGlobalValue(supybot.drivers, 'module',
-    ValidDriverModule('default', _("""Determines what driver module the bot
-    will use.  Socket, a simple driver based on timeout sockets, is used by
-    default because it's simple and stable.  Twisted is very stable and simple,
-    and if you've got Twisted installed, is probably your best bet.""")))
+    ValidDriverModule('default', _("""Determines what driver module the 
+    bot will use. The default is Socket which is simple and stable 
+    and supports SSL. Twisted doesn't work if the IRC server which 
+    you are connecting to has IPv6 (most of them do).""")))
 
 registerGlobalValue(supybot.drivers, 'maxReconnectWait',
     registry.PositiveFloat(300.0, _("""Determines the maximum time the bot will
@@ -1064,6 +1064,10 @@ registerGlobalValue(supybot.protocols.irc, 'strictRfc',
     a nick such as services@this.network.server then you you should set this to
     False.""")))
 
+registerGlobalValue(supybot.protocols.irc, 'certfile',
+    registry.String('', _("""Determines what certificate file (if any) the bot
+    will use connect with SSL sockets by default.""")))
+
 registerGlobalValue(supybot.protocols.irc, 'umodes',
     registry.String('', _("""Determines what user modes the bot will request
     from the server when it first connects.  Many people might choose +i; some
